==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/UserFactorPushTransactionRejectedAllOfLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksVerifyVerify;
import com.okta.sdk.resource.model.UserFactor;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionRejectedAllOfLinks
 */
@JsonPropertyOrder({ UserFactorPushTransactionRejectedAllOfLinks.JSON_PROPERTY_VERIFY,
        UserFactorPushTransactionRejectedAllOfLinks.JSON_PROPERTY_FACTOR })
@JsonTypeName("UserFactorPushTransactionRejected_allOf__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserFactorPushTransactionRejectedAllOfLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private LinksVerifyVerify verify;

    public static final String JSON_PROPERTY_FACTOR = "factor";
    private UserFactor factor;

    public UserFactorPushTransactionRejectedAllOfLinks() {
    }

    public UserFactorPushTransactionRejectedAllOfLinks verify(LinksVerifyVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksVerifyVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(LinksVerifyVerify verify) {
        this.verify = verify;
    }

    public UserFactorPushTransactionRejectedAllOfLinks factor(UserFactor factor) {

        this.factor = factor;
        return this;
    }

    /**
     * Get factor
     *
     * @return factor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactor getFactor() {
        return factor;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactor(UserFactor factor) {
        this.factor = factor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionRejectedAllOfLinks userFactorPushTransactionRejectedAllOfLinks = (UserFactorPushTransactionRejectedAllOfLinks) o;
        return Objects.equals(this.verify, userFactorPushTransactionRejectedAllOfLinks.verify)
                && Objects.equals(this.factor, userFactorPushTransactionRejectedAllOfLinks.factor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(verify, factor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionRejectedAllOfLinks {\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("    factor: ").append(toIndentedString(factor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/UserFactorPushTransactionRejectedAllOfLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksVerifyVerify;
import com.okta.sdk.resource.model.UserFactor;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserFactorPushTransactionRejectedAllOfLinks
 */
@JsonPropertyOrder({ UserFactorPushTransactionRejectedAllOfLinks.JSON_PROPERTY_VERIFY,
        UserFactorPushTransactionRejectedAllOfLinks.JSON_PROPERTY_FACTOR })
@JsonTypeName("UserFactorPushTransactionRejected_allOf__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class UserFactorPushTransactionRejectedAllOfLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_VERIFY = "verify";
    private LinksVerifyVerify verify;

    public static final String JSON_PROPERTY_FACTOR = "factor";
    private UserFactor factor;

    public UserFactorPushTransactionRejectedAllOfLinks() {
    }

    public UserFactorPushTransactionRejectedAllOfLinks verify(LinksVerifyVerify verify) {

        this.verify = verify;
        return this;
    }

    /**
     * Get verify
     *
     * @return verify
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksVerifyVerify getVerify() {
        return verify;
    }

    @JsonProperty(JSON_PROPERTY_VERIFY)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setVerify(LinksVerifyVerify verify) {
        this.verify = verify;
    }

    public UserFactorPushTransactionRejectedAllOfLinks factor(UserFactor factor) {

        this.factor = factor;
        return this;
    }

    /**
     * Get factor
     *
     * @return factor
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public UserFactor getFactor() {
        return factor;
    }

    @JsonProperty(JSON_PROPERTY_FACTOR)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setFactor(UserFactor factor) {
        this.factor = factor;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserFactorPushTransactionRejectedAllOfLinks userFactorPushTransactionRejectedAllOfLinks = (UserFactorPushTransactionRejectedAllOfLinks) o;
        return Objects.equals(this.verify, userFactorPushTransactionRejectedAllOfLinks.verify)
                && Objects.equals(this.factor, userFactorPushTransactionRejectedAllOfLinks.factor);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(verify, factor);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserFactorPushTransactionRejectedAllOfLinks {\n");
        sb.append("    verify: ").append(toIndentedString(verify)).append("\n");
        sb.append("    factor: ").append(toIndentedString(factor)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
